# Ask Me Something
A speech to text library.
# Install
```
pip3 install ask-me-something
```
# Using
The ask function prints and returns the recognized content
## In another script
```python
from ask_me_something import ask

# ask(text = "Say something to mic", language = "en-en")

ask()
```
## In command line
```console
  -h, --help            show this help message and exit
  -l LANGUAGE, --language LANGUAGE
                        Language
```

```console
ask
```